@@ -138,7 +138,7 @@ def runEvaluation(exp, parameters):
     maxSepEffKey = list(exp.keys())[np.argmax(sepEffs)]
 
     # Find the number of unique MS/MS spectra
-    parameters['uniqueMS2'] = [exp[k].getUniqueMS2(returnNum=True) for k in exp.keys()]
+    parameters['uniqueMS2'] = [rawDataHelper.getUniqueMS2(d=exp[k], returnNum=True) for k in exp.keys()]
 
     if maxSepEffKey in parameters["grads"].keys():
         # Find the gradient setting that gives the highest separation efficiency
