@@ -657,7 +657,7 @@ def dotProd(ms2A, ms2B, mzTol=0.02, rep='simple'):
         return {'dotprod': dp, 'matchNumber': matchNum}
 
 
-def numberUniqueMS2(d, rtTol=1.0, precsMzTol=0.01, dpTol=0.95):
+def getUniqueMS2(d, rtTol=1.0, precsMzTol=0.01, dpTol=0.95, returnNum=False):
     """
     Function to calculate the number of unique MS2.
 
@@ -671,11 +671,14 @@ def numberUniqueMS2(d, rtTol=1.0, precsMzTol=0.01, dpTol=0.95):
         Tolerance of precursor m/z, in Da.
     dpTol: float
         Tolerance of dot product.
+    returnNum: boolean
+        True to return the number of unique MS2;
+        False to return the list of unique MS2.
 
     Returns
     ----------------------------------------------------------
     List:
-        Unique MS2 spectra.
+        Unique MS2 spectra (when returnNum is False).
     """
 
     uniqueMS2 = []
@@ -720,7 +723,10 @@ def numberUniqueMS2(d, rtTol=1.0, precsMzTol=0.01, dpTol=0.95):
 
     uniqueMS2 += temp
 
-    return uniqueMS2
+    if returnNum:
+        return len(uniqueMS2)
+    else:
+        return uniqueMS2
 
 
 def getUniqueMz(d, precsMzTol=0.01):
